@@ -1,6 +1,6 @@
 import socket
-from CGPCLI.Parser import parse_to_python_object
-from CGPCLI.Errors import FailedLogin, ConnectionTimeOut, CommandFailedError
+from Parser import parse_to_python_object
+from Errors import FailedLogin, ConnectionTimeOut, CommandFailedError
 
 class CGPConnector:
     def __init__(self, host, port=106):
@@ -97,8 +97,8 @@ class CGPConnector:
         '''Close socket connection'''
         try:
             self.socket.send(('QUIT\n').encode())
-        except ConnectionAbortedError:
+            self.socket.close()
+        except (ConnectionAbortedError, AttributeError):
             pass
         
-        self.socket.close()
         del self.socket
\ No newline at end of file
